from junopass import signatures
from junopass.client import *


class JunoPass(object):
    def __init__(self, access_token, junopass_public_key):
        self.access_token = access_token
        self.junopass_public_key = junopass_public_key

    def setup_device(self):
        """
        Generates device signing key
        Use this only on new devices e.g during setup/registration.
        Consider keeping the keys in a safe place for future use.
        Note the private_key must never be shared.

        Returns a tupple of key pair (private_key, public_key).

        Example:
        from junopass import JunoPass
        jp = JunoPass(<Access-Token>, <JunoPass-Public-Key>)
        private_key, public_key = jp.setup_device()
        """
        return signatures._generate_device_keys()

    def authenticate(self, payload):
        pass



import unittest

from junopass import JunoPass


class TestEncryption(unittest.TestCase):

    def setUp(self):
        access_token = "xx"
        junopass_public_key = "yy"
        self.jp = JunoPass(access_token, junopass_public_key)

    def test_device_setup(self):
        prvtkey, pubkey = self.jp.setup_device()
        self.assertIsNotNone(prvtkey)
        self.assertIsNotNone(pubkey)
        self.assertNotEqual(prvtkey, pubkey)



import requests
import os

JUNOPASS_API_BASE = os.environ.get(
    "JUNOPASS_API_BASE", "https://console.junopass.com/api/v1/")


def _authenticate_request(access_token, payload):
    """
    Send auth request to JunoPass
    Step 1 process
    """
    if not access_token:
        raise Exception("Access token is required")
    headers = {"Authorization": f"Token {access_token}"}
    api_url = f"{JUNOPASS_API_BASE}user/authenticate/"
    resp = requests.post(api_url, json=payload, headers=headers)
    return resp


def _verify_request(access_token, payload):
    """
    Send signed challenges and otp for verification
    """
    if not access_token:
        raise Exception("Access token is required")
    headers = {"Authorization": f"Token {access_token}"}
    api_url = f"{JUNOPASS_API_BASE}user/verify/"
    resp = requests.post(api_url, json=payload, headers=headers)
    return resp



import nacl.encoding
import nacl.signing

def _generate_device_keys():
    """
    Generate device public and private key pairs
    """
    signing_key = nacl.signing.SigningKey.generate()
    private_key = signing_key.encode(encoder=nacl.encoding.HexEncoder)

    verify_key = signing_key.verify_key
    public_key = verify_key.encode(encoder=nacl.encoding.HexEncoder)
    return private_key.decode("utf-8"), public_key.decode("utf-8")


def _sign_message(private_key_hex, message):
    """
    Sign message with your own key i.e device private key
    """
    signing_key = nacl.signing.SigningKey(
        private_key_hex, encoder=nacl.encoding.HexEncoder)
    signed = signing_key.sign(message.encode("utf-8"))
    return signed.hex()


def _verify_junopass_message(public_key, signed_message):
    """
    Verify the authenticity of JunoPass message using its public key.
    Return a boolean as per its status
    """
    verify_key = nacl.signing.VerifyKey(
        public_key, encoder=nacl.encoding.HexEncoder)
    sign_message_byte = bytes.fromhex(signed_message)
    return verify_key.verify(sign_message_byte)



import setuptools
long_description = ""
with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="junopass-py",
    version="1.0.1",
    author="Felix Cheruiyot",
    author_email="felix@junopass.com",
    description="JunoPass support for Python.JunoPass provides a secure 2FA and Passwordless authentication.",
    long_description=long_description,
    url="https://github.com/junopass/junopass-py",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Development Status :: 4 - Beta", 
        "Intended Audience :: Developers", 
        "Topic :: Security", 
        "License :: OSI Approved :: MIT License",
    ],
    python_requires='>=3.6',
)
